CsrOptions

Struct CsrOptions 

pub struct CsrOptions { /* private fields */ }
Holds configuration options for creating a certificate from a Certificate Signing Request (CSR).

Implementations

Source

impl CsrOptions

pub fn new() -> Self

Creates a default CsrOptions instance:

  • valid_from is set to today.
  • valid_to is set to one year from today.
  • ca is set to false.
pub fn valid_from(self, valid_from: &str) -> Self

Sets the start date from which the certificate should be valid.

Arguments
  • valid_from - A string in the format yyyy-mm-dd.
pub fn valid_to(self, valid_to: &str) -> Self

Sets the end date after which the certificate should no longer be valid.

Arguments
  • valid_to - A string in the format yyyy-mm-dd.
pub fn is_ca(self, ca: bool) -> Self

Specifies whether the certificate should be a Certificate Authority (CA).

Arguments
  • ca - true if the certificate should be a CA, false otherwise.
pub fn certificate_policies(self, policies: Vec<CertificatePolicy>) -> Self

Add optional certificate policies

Arguments
  • policies - A list of certificate policies
pub fn pathlen(self, path_len: u32, chain: Vec<Certificate>) -> Self

Add optional path length, it is the max number of non-self-issued intermediate CA certs that may follow this cert in a chain

Arguments
  • path_len- u32