pub struct CsrOptions { /* private fields */ }Expand description
Holds configuration options for creating a certificate from a Certificate Signing Request (CSR).
Implementations
Sourceimpl CsrOptions
impl CsrOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a default CsrOptions instance:
valid_fromis set to today.valid_tois set to one year from today.cais set tofalse.
Sourcepub fn valid_from(self, valid_from: &str) -> Self
pub fn valid_from(self, valid_from: &str) -> Self
Sets the start date from which the certificate should be valid.
Arguments
valid_from- A string in the formatyyyy-mm-dd.
Sourcepub fn valid_to(self, valid_to: &str) -> Self
pub fn valid_to(self, valid_to: &str) -> Self
Sets the end date after which the certificate should no longer be valid.
Arguments
valid_to- A string in the formatyyyy-mm-dd.
Sourcepub fn is_ca(self, ca: bool) -> Self
pub fn is_ca(self, ca: bool) -> Self
Specifies whether the certificate should be a Certificate Authority (CA).
Arguments
ca-trueif the certificate should be a CA,falseotherwise.
Sourcepub fn certificate_policies(self, policies: Vec<CertificatePolicy>) -> Self
pub fn certificate_policies(self, policies: Vec<CertificatePolicy>) -> Self